@@ -97,9 +97,9 @@ function (object, col = ggplot2::GeomRect$default_aes$fill,
           border = ggplot2::GeomRect$default_aes$colour, ...) 
 {
   thePlot <- ggplot2::ggplot() +
-    ggplot2::geom_rect(ggplot2::aes_(xmin=~xmin, ymin=~ymin, xmax=~xmax, ymax=~ymax), 
+    ggplot2::geom_rect(ggplot2::aes(xmin=.data$xmin, ymin=.data$ymin, xmax=.data$xmax, ymax=.data$ymax), 
                        data.frame(xmin=0, ymin=0, xmax=object$GammaDiversity, ymax=1), alpha=0.3, colour=border, fill=col) +
-    ggplot2::geom_rect(ggplot2::aes_(xmin=~xmin, ymin=~ymin, xmax=~xmax, ymax=~ymax), 
+    ggplot2::geom_rect(ggplot2::aes(xmin=.data$xmin, ymin=.data$ymin, xmax=.data$xmax, ymax=.data$ymax), 
                        data.frame(xmin=0, ymin=0, xmax=object$TotalAlphaDiversity, ymax=object$TotalBetaDiversity), alpha=0.3, colour=border, fill=col) +
     ggplot2::expand_limits(y=c(0, length(object$CommunityAlphaDiversities))) +
     ggplot2::labs(x=expression(paste(alpha, " and ", gamma, " diversity")), y=expression(paste(beta, " diversity"))) +
